Avec cette librairie, vous pouvez acquérir tous les synonymes de n'importe quel mot en français:
```python
>>> from synonymes.synonymes.synonymes import linternaute
>>> list(linternaute('jonché'))
['couvert', 'disséminé', 'parsemé', 'recouvert', 'tapissé']
```
Vous pouvez aussi utiliser larousse, synonymo et cnrtl (je vous le recommande le plus)